Module validation

Module validation 

Validating and caching of a manifest

This module contains the code for the validation and caching of a manifest and is directly used by the the validate and cache command.

Functions

cache_manifest
Caches a manifest file to the Database/Cache
validate_manifest
Validates a manifest file and further more validates the cache if possible.